[![image](https://cosmo-gitlab.phys.ethz.ch/silvanf/cosmic_toolbox/badges/main/pipeline.svg)](https://cosmo-gitlab.phys.ethz.ch/silvanf/cosmic_toolbox)
[![Latest Release](https://cosmo-gitlab.phys.ethz.ch/silvanf/cosmic_toolbox/-/badges/release.svg)](https://cosmo-gitlab.phys.ethz.ch/silvanf/cosmic_toolbox/-/releases/)
[![PyPI version](https://badge.fury.io/py/cosmic_toolbox.svg)](https://badge.fury.io/py/cosmic_toolbox)

# cosmic_toolbox

Collection of code from the Cosmology Research Group at ETH


## Features

* TODO

